==> HMC_Update_V4R1.3.zip: opt/ccfw/help/base/nl/en/basehelp.hs <==
<?xml version="1.0" encoding="ISO-8859-1" ?>
<!DOCTYPE helpset
 PUBLIC 
"-//Sun Microsystems Inc.//DTD JavaHelp HelpSet Version 1.0//EN"
"http://java.sun.com/products/javahelp/helpset_1_0.dtd">
<helpset version="1.0">
 <title>Base Tasks and Console Help</title>
<maps>

</maps>
<view>
<type>javax.help.TOCView</type>
<name>Contents</name>
<label>Contents</label>

</view>

<subhelpset location="com/ibm/hwmca/base/aaconfig/res/AutoAnswerConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/logon/res/LogonRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/saverest/res/SaveRestoreRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/saverest/res/Saveres.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/network/res/NetworkRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/acctinfo/res/AcctinfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/autologon/res/CustomizeAutomaticLogonRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/peaccess/res/ProductEngineeringAccessRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/res/BaseSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/snmp/res/SnmpRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ConfirmationSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ObjectBackgroundSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ObjectLockingSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/UserSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/sysinfo/res/SystemInfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/AnalyzeConsoleIntCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ChangeConsoleIntCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ChangeInternalCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ConsoleSingleStepMclRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/RetrieveInternalCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/hmcservc/res/HmcServicesRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/time/res/CustDateTimeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rsf/dialcfg/res/DialConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rsf/res/RsfRequestsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/remsrv/res/RemoteServiceRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/custinfo/res/CustomerInfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/authcode/res/AuthInternalCodeChangeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/bpcrcon/res/BackupCriticalConsoleDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/tsd/res/TransSrvDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/activate/res/ConfirmActivateRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/actprof/res/ActivationProfileListRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/arcslogs/res/ArchiveSecurityLogsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/domsec/res/DomainSecurityRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/eventmon/res/EventMonitor.hs"/>
<subhelpset location="com/ibm/hwmca/base/filed/res/FileDialogRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/fmtmedia/res/FormatMediaRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/grouping/res/GroupingRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/hmcconfg/res/HmcConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/modemcfg/res/ModemConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/netdiag/res/NetworkDiagnosticInformationRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/ntfy/res/NotificationRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/userprof/res/UserProfRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/remconsq/res/RemoteConnectionServicesRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rescrcon/res/RestoreCriticalConsoleDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rptprob/res/ReportProblemRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/upgrddat/res/UpgradeDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/trace/res/ConsoleTraceRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/userrole/res/UserRoleRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vconevnt/res/ViewConsoleEventsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vpd/res/TransmitVpdRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vpd/res/RebuildVpdRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vseclogs/res/ViewSecurityLogsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/task/res/ProgressRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/task/res/TaskRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/attn/res/HwMessagesRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/schedops/res/SchedOpsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rsf/managereqs/res/RsfRequestsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/outconn/res/OutboundConnRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/modemcfg/res/ModemConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/manageconns/res/RcsConnectionsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/target/res/TargetRes.hs"/>
<subhelpset location="com/ibm/hwmca/xfw/panel/pa/res/ProblemAnalysisRes.hs"/>
<subhelpset location="com/ibm/hwmca/xfw/panel/repair/res/PerformConsoleRepActRes.hs"/>
</helpset>

==> HMC_Update_V4R2.0.zip: opt/ccfw/help/base/nl/en/basehelp.hs <==
<?xml version="1.0" encoding="ISO-8859-1" ?>
<!DOCTYPE helpset
 PUBLIC 
"-//Sun Microsystems Inc.//DTD JavaHelp HelpSet Version 1.0//EN"
"http://java.sun.com/products/javahelp/helpset_1_0.dtd">
<helpset version="1.0">
 <title>Base Tasks and Console Help</title>
<maps>

</maps>
<view>
<type>javax.help.TOCView</type>
<name>Contents</name>
<label>Contents</label>

</view>

<subhelpset location="com/ibm/hwmca/base/aaconfig/res/AutoAnswerConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/logon/res/LogonRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/saverest/res/SaveRestoreRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/saverest/res/Saveres.hs"/>
<subhelpset location="com/ibm/hwmca/base/saverest/res/CustDataRepWarning.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/acctinfo/res/AcctinfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/network/res/NetworkRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/autologon/res/CustomizeAutomaticLogonRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/peaccess/res/ProductEngineeringAccessRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/snmp/res/SnmpRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/snmp/res/tabpanel/SnmpTabRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ConfirmationSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ObjectBackgroundSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/ObjectLockingSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/settings/user/res/UserSettingsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/sysinfo/res/SystemInfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/domsec/res/DomainSecurityRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/AnalyzeConsoleIntCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ChangeConsoleIntCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ChangeInternalCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/ConsoleSingleStepMclRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/updates/res/RetrieveInternalCodeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/hmcservc/res/HmcServicesRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/time/res/CustDateTimeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rsf/dialcfg/res/DialConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rsf/res/RsfRequestsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/remsrv/res/RemoteServiceRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/custinfo/res/CustomerInfoRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/authcode/res/AuthInternalCodeChangeRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/bpcrcon/res/BackupCriticalConsoleDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/tsd/res/TransSrvDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/activate/res/ConfirmActivateRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/actprof/res/ActivationProfileListRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/arcslogs/res/ArchiveSecurityLogsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/eventmon/res/EventMonitor.hs"/>
<subhelpset location="com/ibm/hwmca/base/filed/res/FileDialogRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/fmtmedia/res/FormatMediaRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/grouping/res/GroupingRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/hmcconfg/res/HmcConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/modemcfg/res/ModemConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/netdiag/res/NetworkDiagnosticInformationRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/ntfy/res/NotificationRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/userprof/res/UserProfRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/remconsq/res/RemoteConnectionServicesRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rescrcon/res/RestoreCriticalConsoleDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/rptprob/res/ReportProblemRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/upgrddat/res/UpgradeDataRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/shutdown/res/shutdown.hs"/>
<subhelpset location="com/ibm/hwmca/base/trace/res/ConsoleTraceRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/userrole/res/UserRoleRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vconevnt/res/ViewConsoleEventsRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vpd/res/TransmitVpdRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vpd/res/RebuildVpdRes.hs"/>
<subhelpset location="com/ibm/hwmca/base/vseclogs/res/ViewSecurityLogsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/task/res/ProgressRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/task/res/TaskRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/attn/res/HwMessagesRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/schedops/res/SchedOpsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rsf/managereqs/res/RsfRequestsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/outconn/res/OutboundConnRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/modemcfg/res/ModemConfigRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/rcs/manageconns/res/RcsConnectionsRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/target/res/TargetRes.hs"/>
<subhelpset location="com/ibm/hwmca/fw/certs/res/CertMgt.hs"/>
<subhelpset location="com/ibm/hwmca/xfw/panel/pa/res/ProblemAnalysisRes.hs"/>
<subhelpset location="com/ibm/hwmca/xfw/panel/repair/res/PerformConsoleRepActRes.hs"/>
</helpset>
